@@ -1,9 +1,11 @@
 from datetime import datetime
+from distutils import core
 import subprocess
 import os
 import setuptools
 import sys
 from ..helpers.revision import Revision
+from ..helpers.import_scope import ImportScope
 from .exceptions import ParsingError
 
 
@@ -22,6 +24,7 @@ class GitParser(object):
     def _patch_setuptools(self):
         """Patch setuptools"""
         setuptools.setup = self._store_args
+        core.setup = self._store_args
 
     def _get_commit_datetime(self, commit=None):
         """Get commit date, if None - use current commit"""
@@ -44,9 +47,15 @@ class GitParser(object):
         """Store arguments to setup"""
         self._data = kwargs
 
-    def _get_revisions_with_changes(self):
-        """Get revisions with changes"""
-        out = self._git('log', '--pretty=format:%h', 'setup.py')
+    def _get_revisions_with_setup_py(self):
+        """Get revisions with setup.py"""
+        from_revision = self._git('log', '--pretty=format:%h', 'setup.py')\
+            .readlines()[-1][:-1]
+        to_revision = self._git('log', '--pretty=format:%h', '-n', '1')\
+            .readline()[:-1]
+        out = self._git('log', '--pretty=format:%h', '{}..{}'.format(
+            from_revision, to_revision,
+        ))
         return [
             line[:-1] for line in out.readlines()
             if self._is_before_current(line[:-1])
@@ -55,14 +64,15 @@ class GitParser(object):
     def _get_commits_with_versions(self, commits):
         """Get commits with versions"""
         versions = []
-        setup = None
         for commit in commits:
             with Revision(commit, self._path) as revision:
                 sys.path.insert(0, revision.destination)
-                if setup is None:
-                    setup = __import__('setup')
-                else:
-                    reload(setup)
+                with ImportScope():
+                    try:
+                        __import__('setup')
+                    except Exception as e:
+                        print e
+                        continue
             if not self._data['version'] in versions:
                 versions.append(self._data['version'])
                 yield commit, self._data['version']
@@ -74,7 +84,7 @@ class GitParser(object):
             '{}...{}'.format(start, end) if start else end,
         )
         return [
-            line.replace('\n', '').replace('\r', '')
+            line.replace('\n', '').replace('\r', '').decode('utf8')
             for line in out.readlines()
         ]
 
@@ -105,6 +115,6 @@ class GitParser(object):
         self._set_path(path)
         self._set_current_commit_date()
         self._patch_setuptools()
-        changes = self._get_revisions_with_changes()
+        changes = self._get_revisions_with_setup_py()
         version_pairs = self._get_commits_with_versions(changes)
         return list(self._create_change_logs(version_pairs))
